Learn R Programming

toprdata (version 1.0.2)

ENSEXONS_37: Ensembl exons build HG37 (GRCh37) v40 from gencode

Description

exons on chrY and chrM were excluded from the exon dataset

Usage

ENSEXONS_37

Arguments

Format

A data frame with 62,739 rows and 7 variables:

chrom

Chromosome on build version 38 (GRCh38/hg38)

gene_start

genetic position of gene start on build version 38

gene_end

genetic position of gene end on build version 38

gene_symbol

The name of the gene

exon_chromstart

genetic positions of exon start

exon_chromend

genetic position of exon end