Learn R Programming

toprdata (version 1.0.2)

ENSGENES_37: Ensembl genes build HG37 (GRCh37) v40 from gencode

Description

genes on chrY and chrM were excluded

Usage

ENSGENES_37

Arguments

Format

A data frame with 62,743 rows and 5 variables:

chrom

Chromosome on build version 38 (GRCh38/hg38)

gene_start

genetic position of gene start on build version 38

gene_end

genetic position of gene end on build version 38

gene_symbol

The name of the gene

biotype

the biotype of the gene